@@ -30,7 +30,7 @@ class BaseCanvas(object):
 		for d in self.draw_queue:
 			print(d)
 
-	def save(self, filename):
+	def save(self, filename, open_viewer=False):
 		svg_canvas = drawSvg.Drawing(self.width, self.height, origin=(0, 0), displayInline=False)
 
 		# There may be a better way to do this through the init above, but I found it confusing.
@@ -58,6 +58,7 @@ class BaseCanvas(object):
 
 				verts = shape.verticies
 
+
 				# verts = vertices.tolist()
 				if verts == [[0.0, 0.0, 0.0]]:
 					# print(f'verts contains one item of {[[0.0, 0.0, 0.0]]} ... continuing.')
@@ -91,6 +92,10 @@ class BaseCanvas(object):
 
 		svg_canvas.saveSvg(filename)
 
+		if open_viewer:
+			import webbrowser
+			webbrowser.open('http://example.com')  # Go to example.com
+
 	def flush(self):
 		self.draw_queue=[]
 
